@@ -1,6 +1,6 @@
 /* gdaui-basic-form.c
  *
- * Copyright (C) 2002 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2002 - 2010 Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -130,6 +130,17 @@ enum {
 	PROP_CAN_EXPAND
 };
 
+typedef struct {
+	GtkSizeGroup *size_group; /* ref held here */
+	GdauiBasicFormPart part;
+} SizeGroup;
+static void
+size_group_free (SizeGroup *sg)
+{
+	g_object_unref (sg->size_group);
+	g_free (sg);
+}
+
 struct _GdauiBasicFormPriv
 {
 	GdaSet                 *set;
@@ -143,6 +154,8 @@ struct _GdauiBasicFormPriv
 	gboolean                forward_param_updates; /* forward them to the GdauiDataEntry widgets ? */
 	gboolean                show_actions;
 	gboolean                entries_auto_default;
+
+	GSList                 *size_groups; /* list of SizeGroup pointers */
 };
 
 
@@ -286,23 +299,23 @@ gdaui_basic_form_init (GdauiBasicForm * wid)
 
 /**
  * gdaui_basic_form_new
- * @paramlist: a #GdaSet structure
+ * @data_set: a #GdaSet structure
  *
- * Creates a new #GdauiBasicForm widget using all the parameters provided in @paramlist.
+ * Creates a new #GdauiBasicForm widget using all the #GdaHolder objects provided in @data_set.
  *
  * The global layout is rendered using a table (a #GtkTable), and an entry is created for each
- * node of @paramlist.
+ * node of @data_set.
  *
  * Returns: the new widget
  *
  * Since: 4.2
  */
 GtkWidget *
-gdaui_basic_form_new (GdaSet *paramlist)
+gdaui_basic_form_new (GdaSet *data_set)
 {
 	GObject *obj;
 
-	obj = g_object_new (GDAUI_TYPE_BASIC_FORM, "paramlist", paramlist, NULL);
+	obj = g_object_new (GDAUI_TYPE_BASIC_FORM, "paramlist", data_set, NULL);
 
 	return (GtkWidget *) obj;
 }
@@ -430,6 +443,11 @@ gdaui_basic_form_dispose (GObject *object)
 
 		destroy_entries (form);
 
+		if (form->priv->size_groups) {
+			g_slist_foreach (form->priv->size_groups, (GFunc) size_group_free, NULL);
+			g_slist_free (form->priv->size_groups);
+		}
+
 		/* the private area itself */
 		g_free (form->priv);
 		form->priv = NULL;
@@ -710,12 +728,18 @@ create_entry_widget (SingleEntry *sentry)
 		entry = GTK_WIDGET (gdaui_new_data_entry (type, plugin));
 
 		/* set current value */
-		gdaui_data_entry_set_value (GDAUI_DATA_ENTRY (entry), val);
+		if (gda_holder_is_valid (param))
+			gdaui_data_entry_set_value (GDAUI_DATA_ENTRY (entry), val);
+		else {
+			GValue value;
+			memset (&value, 0, sizeof (GValue));
+			gdaui_data_entry_set_value (GDAUI_DATA_ENTRY (entry), &value);
+		}
 
 		if (!nnul ||
 		    (nnul && value &&
 		     (G_VALUE_TYPE ((GValue *) value) != GDA_TYPE_NULL)))
-			gdaui_data_entry_set_original_value (GDAUI_DATA_ENTRY (entry), value);
+			gdaui_data_entry_set_reference_value (GDAUI_DATA_ENTRY (entry), value);
 
 		if (default_val) {
 			gdaui_data_entry_set_value_default (GDAUI_DATA_ENTRY (entry), default_val);
@@ -820,6 +844,23 @@ create_entry_widget (SingleEntry *sentry)
 	g_object_ref_sink (sentry->entry);
 	gdaui_data_entry_set_editable (sentry->entry, editable);
 
+	GSList *list;
+	for (list = sentry->form->priv->size_groups; list; list = list->next) {
+		SizeGroup *sg = (SizeGroup*) list->data;
+		switch (sg->part) {
+		case GDAUI_BASIC_FORM_LABELS:
+			if (sentry->label)
+				gtk_size_group_add_widget (sg->size_group, sentry->label);
+			break;
+		case GDAUI_BASIC_FORM_ENTRIES:
+			if (sentry->entry)
+				gtk_size_group_add_widget (sg->size_group, GTK_WIDGET (sentry->entry));
+			break;
+		default:
+			g_assert_not_reached ();
+		}
+	}
+
 	/* connect the entry's changes */
 	sentry->entry_contents_modified_id = g_signal_connect (G_OBJECT (entry), "contents-modified",
 							       G_CALLBACK (entry_contents_modified),
@@ -1226,7 +1267,9 @@ entry_contents_modified (GdauiDataEntry *entry, SingleEntry *sentry)
 			/* GdaHolder refused value => reset GdaDataEntry */
 			g_signal_handler_block (G_OBJECT (entry),
 						sentry->entry_contents_modified_id);
-			gdaui_data_entry_set_value (entry, gda_holder_get_value (param));
+			gdaui_data_entry_set_value (entry,
+						    gda_holder_is_valid (param) ?
+						    gda_holder_get_value (param) : NULL);
 			g_signal_handler_unblock (G_OBJECT (entry),
 						  sentry->entry_contents_modified_id);
 		}
@@ -1331,7 +1374,7 @@ parameter_changed_cb (GdaHolder *param, SingleEntry *sentry)
 		}
 
 		if (sentry->single_param)
-			gdaui_data_entry_set_value (entry, value);
+			gdaui_data_entry_set_value (entry, param_valid ? value : NULL);
 		else {
 			GSList *values = NULL;
 			GSList *list;
@@ -1393,7 +1436,7 @@ gdaui_basic_form_set_as_reference (GdauiBasicForm *form)
 			param = sentry->single_param;
 			g_signal_handler_block (G_OBJECT (sentry->entry),
 						sentry->entry_contents_modified_id);
-			gdaui_data_entry_set_original_value (GDAUI_DATA_ENTRY (sentry->entry),
+			gdaui_data_entry_set_reference_value (GDAUI_DATA_ENTRY (sentry->entry),
 							     gda_holder_get_value (param));
 			g_signal_handler_unblock (G_OBJECT (sentry->entry),
 						  sentry->entry_contents_modified_id);
@@ -1533,7 +1576,7 @@ gdaui_basic_form_reset (GdauiBasicForm *form)
 	for (list = form->priv->s_entries; list; list = list->next) {
 		SingleEntry *sentry = (SingleEntry*) list->data;
 
-		if (sentry->group) {
+		if (!sentry->single_param) {
 			/* Combo entry */
 			GSList *values = NULL;
 
@@ -1732,7 +1775,7 @@ get_single_entry_for_holder (GdauiBasicForm *form, GdaHolder *param)
 		SingleEntry *sentry = (SingleEntry *) list->data;
 		if (sentry->single_param && (sentry->single_param == param))
 			return sentry;
-		else if (sentry->group) {
+		else if (! sentry->single_param) {
 			/* multiple parameters */
 			GSList *params;
 
@@ -1817,7 +1860,7 @@ gdaui_basic_form_get_label_widget (GdauiBasicForm *form, GdaHolder *param)
 
 /**
  * gdaui_basic_form_new_in_dialog
- * @paramlist: a #GdaSet structure
+ * @data_set: a #GdaSet object
  * @parent: the parent window for the new dialog, or %NULL
  * @title: the title of the dialog window, or %NULL
  * @header: a helper text displayed at the top of the dialog, or %NULL
@@ -1834,14 +1877,14 @@ gdaui_basic_form_get_label_widget (GdauiBasicForm *form, GdaHolder *param)
  * Since: 4.2
  */
 GtkWidget *
-gdaui_basic_form_new_in_dialog (GdaSet *paramlist, GtkWindow *parent,
+gdaui_basic_form_new_in_dialog (GdaSet *data_set, GtkWindow *parent,
 				const gchar *title, const gchar *header)
 {
 	GtkWidget *form;
 	GtkWidget *dlg;
 	const gchar *rtitle;
 
-	form = gdaui_basic_form_new (paramlist);
+	form = gdaui_basic_form_new (data_set);
 
 	rtitle = title;
 	if (!rtitle)
@@ -1995,3 +2038,95 @@ gdaui_basic_form_get_place_holder (GdauiBasicForm *form, const gchar *placeholde
 		return NULL;
 	return g_hash_table_lookup (form->priv->place_holders, placeholder_id);
 }
+
+/**
+ * gdaui_basic_form_add_to_size_group
+ * @form: a #GdauiBasicForm
+ * @size_group: a #GtkSizeGroup object
+ * @part: specifies which widgets in @form are concerned
+ *
+ * Add @form's widgets specified by @part to @size_group
+ * (the widgets can then be removed using gdaui_basic_form_remove_from_size_group()).
+ *
+ * Since: 4.2
+ */
+void
+gdaui_basic_form_add_to_size_group (GdauiBasicForm *form, GtkSizeGroup *size_group, GdauiBasicFormPart part)
+{
+	GSList *list;
+	g_return_if_fail (GDAUI_IS_BASIC_FORM (form));
+	g_return_if_fail (GTK_IS_SIZE_GROUP (size_group));
+
+	SizeGroup *sg;
+	sg = g_new (SizeGroup, 1);
+	sg->size_group = g_object_ref (size_group);
+	sg->part = part;
+	form->priv->size_groups = g_slist_append (form->priv->size_groups, sg);
+
+	for (list = form->priv->s_entries; list; list = list->next) {
+		SingleEntry *se = (SingleEntry*) list->data;
+		switch (part) {
+		case GDAUI_BASIC_FORM_LABELS:
+			if (se->label)
+				gtk_size_group_add_widget (size_group, se->label);
+			break;
+		case GDAUI_BASIC_FORM_ENTRIES:
+			if (se->entry)
+				gtk_size_group_add_widget (size_group, GTK_WIDGET (se->entry));
+			break;
+		default:
+			g_assert_not_reached ();
+		}
+	}
+}
+
+/**
+ * gdaui_basic_form_remove_from_size_group
+ * @form: a #GdauiBasicForm
+ * @size_group: a #GtkSizeGroup object
+ * @part: specifies which widgets in @form are concerned
+ *
+ * Removes @form's widgets specified by @part from @size_group
+ * (the widgets must have been added using gdaui_basic_form_add_to_size_group()).
+ *
+ * Since: 4.2
+ */
+void
+gdaui_basic_form_remove_from_size_group (GdauiBasicForm *form, GtkSizeGroup *size_group, GdauiBasicFormPart part)
+{
+	GSList *list;
+	g_return_if_fail (GDAUI_IS_BASIC_FORM (form));
+	g_return_if_fail (GTK_IS_SIZE_GROUP (size_group));
+	
+	SizeGroup *sg;
+	for (list = form->priv->size_groups; list; list = list->next) {
+		sg = (SizeGroup*) list->data;
+		if (sg->size_group == size_group) {
+			form->priv->size_groups = g_slist_remove (form->priv->size_groups, sg);
+			size_group_free (sg);
+			break;
+		}
+		sg = NULL;
+	}
+
+	if (!sg) {
+		g_warning (_("size group was not taken into account using gdaui_basic_form_add_to_size_group()"));
+		return;
+	}
+
+	for (list = form->priv->s_entries; list; list = list->next) {
+		SingleEntry *se = (SingleEntry*) list->data;
+		switch (part) {
+		case GDAUI_BASIC_FORM_LABELS:
+			if (se->label)
+				gtk_size_group_remove_widget (size_group, se->label);
+			break;
+		case GDAUI_BASIC_FORM_ENTRIES:
+			if (se->entry)
+				gtk_size_group_remove_widget (size_group, GTK_WIDGET (se->entry));
+			break;
+		default:
+			g_assert_not_reached ();
+		}
+	}
+}
