@@ -59,6 +59,10 @@ typedef enum {
 	GDA_SERVER_OPERATION_COMMENT_TABLE,
 	GDA_SERVER_OPERATION_COMMENT_COLUMN,
 
+	GDA_SERVER_OPERATION_CREATE_USER,
+	GDA_SERVER_OPERATION_ALTER_USER,
+	GDA_SERVER_OPERATION_DROP_USER,
+
 	GDA_SERVER_OPERATION_LAST
 } GdaServerOperationType;
 
