@@ -53,8 +53,8 @@ typedef struct {
 
 struct _GdaSqlBuilderPrivate {
 	GdaSqlStatement *main_stmt;
-	GHashTable *parts_hash; /* key = part ID as an guint, value = SqlPart */
-	guint next_assigned_id;
+	GHashTable *parts_hash; /* key = part ID as an GdaSqlBuilderId, value = SqlPart */
+	GdaSqlBuilderId next_assigned_id;
 };
 
 
@@ -269,12 +269,12 @@ gda_sql_builder_get_property (GObject *object,
 	}
 }
 
-static guint
+static GdaSqlBuilderId
 add_part (GdaSqlBuilder *builder, GdaSqlAnyPart *part)
 {
 	SqlPart *p;
-	guint *realid = g_new0 (guint, 1);
-	const guint id = builder->priv->next_assigned_id --;
+	GdaSqlBuilderId *realid = g_new0 (GdaSqlBuilderId, 1);
+	const GdaSqlBuilderId id = builder->priv->next_assigned_id --;
 	*realid = id;
 	p = g_new0 (SqlPart, 1);
 	p->part = part;
@@ -283,10 +283,10 @@ add_part (GdaSqlBuilder *builder, GdaSqlAnyPart *part)
 }
 
 static SqlPart *
-get_part (GdaSqlBuilder *builder, guint id, GdaSqlAnyPartType req_type)
+get_part (GdaSqlBuilder *builder, GdaSqlBuilderId id, GdaSqlAnyPartType req_type)
 {
 	SqlPart *p;
-	guint lid = id;
+	GdaSqlBuilderId lid = id;
 	if (id == 0)
 		return NULL;
 	p = g_hash_table_lookup (builder->priv->parts_hash, &lid);
@@ -437,7 +437,7 @@ gda_sql_builder_set_table (GdaSqlBuilder *builder, const gchar *table_name)
  * Since: 4.2
  */
 void
-gda_sql_builder_set_where (GdaSqlBuilder *builder, guint cond_id)
+gda_sql_builder_set_where (GdaSqlBuilder *builder, GdaSqlBuilderId cond_id)
 {
 	g_return_if_fail (GDA_IS_SQL_BUILDER (builder));
 	g_return_if_fail (builder->priv->main_stmt);
@@ -488,11 +488,13 @@ gda_sql_builder_set_where (GdaSqlBuilder *builder, guint cond_id)
  *
  * Add a selected selected item to the SELECT statement.
  *
+ * For non-SELECT statements, see gda_sql_builder_add_field_id().
+ *
  * Returns: the ID of the added field, or 0 if there was an error
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_select_add_field (GdaSqlBuilder *builder, const gchar *field_name, const gchar *table_name, const gchar *alias)
 {
 	gchar *tmp;
@@ -509,13 +511,13 @@ gda_sql_builder_select_add_field (GdaSqlBuilder *builder, const gchar *field_nam
 	else
 		tmp = (gchar*) field_name;
 
-	const guint field_id = gda_sql_builder_add_id (builder, tmp);
+	const GdaSqlBuilderId field_id = gda_sql_builder_add_id (builder, tmp);
 	if (alias && *alias)
-		gda_sql_builder_add_field_id (builder,
+		gda_sql_builder_add_field_value_id (builder,
 					      field_id,
 					      gda_sql_builder_add_id (builder, alias));
 	else
-		gda_sql_builder_add_field_id (builder,
+		gda_sql_builder_add_field_value_id (builder,
 					      field_id,
 					      0);
 	if (table_name)
@@ -540,7 +542,7 @@ create_typed_value (GType type, va_list *ap)
 }
 
 /**
- * gda_sql_builder_add_field
+ * gda_sql_builder_add_field_value
  * @builder: a #GdaSqlBuilder object
  * @field_name: a field name
  * @type: the GType of the following argument
@@ -551,10 +553,12 @@ create_typed_value (GType type, va_list *ap)
  * Specifies that the field represented by @field_name will be set to the value identified
  * by @... of type @type.
  *
+ * This is a C convenience function. See also gda_sql_builder_add_field_value_as_gvalue().
+ *
  * Since: 4.2
  */
 void
-gda_sql_builder_add_field (GdaSqlBuilder *builder, const gchar *field_name, GType type, ...)
+gda_sql_builder_add_field_value (GdaSqlBuilder *builder, const gchar *field_name, GType type, ...)
 {
 	g_return_if_fail (GDA_IS_SQL_BUILDER (builder));
 	g_return_if_fail (builder->priv->main_stmt);
@@ -566,7 +570,7 @@ gda_sql_builder_add_field (GdaSqlBuilder *builder, const gchar *field_name, GTyp
 		return;
 	}
 
-	guint id1, id2;
+	GdaSqlBuilderId id1, id2;
 	GValue *value;
 	va_list ap;
 
@@ -579,11 +583,11 @@ gda_sql_builder_add_field (GdaSqlBuilder *builder, const gchar *field_name, GTyp
 	id1 = gda_sql_builder_add_id (builder, field_name);
 	id2 = gda_sql_builder_add_expr_value (builder, NULL, value);
 	gda_value_free (value);
-	gda_sql_builder_add_field_id (builder, id1, id2);
+	gda_sql_builder_add_field_value_id (builder, id1, id2);
 }
 
 /**
- * gda_sql_builder_add_field_value
+ * gda_sql_builder_add_field_value_as_gvalue
  * @builder: a #GdaSqlBuilder object
  * @field_name: a field name
  * @value: value to set the field to, or %NULL or a GDA_TYPE_NULL value to represent an SQL NULL
@@ -596,7 +600,7 @@ gda_sql_builder_add_field (GdaSqlBuilder *builder, const gchar *field_name, GTyp
  * Since: 4.2
  */
 void
-gda_sql_builder_add_field_value (GdaSqlBuilder *builder, const gchar *field_name, const GValue *value)
+gda_sql_builder_add_field_value_as_gvalue (GdaSqlBuilder *builder, const gchar *field_name, const GValue *value)
 {
 	g_return_if_fail (GDA_IS_SQL_BUILDER (builder));
 	g_return_if_fail (builder->priv->main_stmt);
@@ -608,14 +612,14 @@ gda_sql_builder_add_field_value (GdaSqlBuilder *builder, const gchar *field_name
 		return;
 	}
 
-	guint id1, id2;
+	GdaSqlBuilderId id1, id2;
 	id1 = gda_sql_builder_add_id (builder, field_name);
 	id2 = gda_sql_builder_add_expr_value (builder, NULL, value);
-	gda_sql_builder_add_field_id (builder, id1, id2);
+	gda_sql_builder_add_field_value_id (builder, id1, id2);
 }
 
 /**
- * gda_sql_builder_add_field_id
+ * gda_sql_builder_add_field_value_id
  * @builder: a #GdaSqlBuilder object
  * @field_id: the ID of the field's name or definition
  * @value_id: the ID of the value to set the field to, or %0
@@ -632,10 +636,13 @@ gda_sql_builder_add_field_value (GdaSqlBuilder *builder, const gchar *field_name
  *    If @field_id represents a sub SELECT (obtained using gda_sql_builder_add_sub_select()), then
  *    this method call defines the sub SELECT from which values to insert are taken.</para></listitem>
  * </itemizedlist>
+ *
+ * See also gda_sql_builder_add_field_value() and gda_sql_builder_add_field_value_as_gvalue().
+ *
  * Since: 4.2
  */
 void
-gda_sql_builder_add_field_id (GdaSqlBuilder *builder, guint field_id, guint value_id)
+gda_sql_builder_add_field_value_id (GdaSqlBuilder *builder, GdaSqlBuilderId field_id, GdaSqlBuilderId value_id)
 {
 	g_return_if_fail (GDA_IS_SQL_BUILDER (builder));
 	g_return_if_fail (builder->priv->main_stmt);
@@ -743,7 +750,7 @@ gda_sql_builder_add_field_id (GdaSqlBuilder *builder, guint field_id, guint valu
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, GdaDataHandler *dh, const GValue *value)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
@@ -812,7 +819,7 @@ gda_sql_builder_add_expr_value (GdaSqlBuilder *builder, GdaDataHandler *dh, cons
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_add_expr (GdaSqlBuilder *builder, GdaDataHandler *dh, GType type, ...)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
@@ -820,7 +827,7 @@ gda_sql_builder_add_expr (GdaSqlBuilder *builder, GdaDataHandler *dh, GType type
 
 	va_list ap;
 	GValue *value;
-	guint retval;
+	GdaSqlBuilderId retval;
 
 	va_start (ap, type);
 	value = create_typed_value (type, &ap);
@@ -841,7 +848,9 @@ gda_sql_builder_add_expr (GdaSqlBuilder *builder, GdaDataHandler *dh, GType type
  * @string: a string
  *
  * Defines an expression representing an identifier in @builder,
- * which may be reused to build other parts of a statement.
+ * which may be reused to build other parts of a statement,
+ * for instance as a parameter to gda_sql_builder_add_cond() or
+ * gda_sql_builder_add_field_value_id().
  *
  * The new expression will contain the @string literal.
  * For example:
@@ -858,11 +867,13 @@ gda_sql_builder_add_expr (GdaSqlBuilder *builder, GdaDataHandler *dh, GType type
  *
  * because "date" is an SQL reserved keyword.
  *
+ * For fields, see gda_sql_builder_add_field_id().
+ *
  * Returns: the ID of the new expression, or 0 if there was an error
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_add_id (GdaSqlBuilder *builder, const gchar *string)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
@@ -879,6 +890,42 @@ gda_sql_builder_add_id (GdaSqlBuilder *builder, const gchar *string)
 	return add_part (builder, (GdaSqlAnyPart *) expr);
 }
 
+/**
+ * gda_sql_builder_add_field_id
+ * @builder: a #GdaSqlBuilder object
+ * @field_name: a field name
+ * @table_name: a table name, or %NULL
+ *
+ * Defines an expression representing a field in @builder,
+ * which may be reused to build other parts of a statement,
+ * for instance as a parameter to gda_sql_builder_add_cond() or
+ * gda_sql_builder_add_field_value_id().
+ *
+ * Calling this with a %NULL @table_name is equivalent to calling gda_sql_builder_add_id().
+ *
+ * For SELECT queries, see gda_sql_builder_select_add_field().
+ *
+ * Returns: the ID of the new expression, or 0 if there was an error
+ *
+ * Since: 4.2
+ */
+GdaSqlBuilderId
+gda_sql_builder_add_field_id (GdaSqlBuilder *builder, const gchar *field_name, const gchar *table_name)
+{
+	gchar* tmp = 0;
+	if (table_name && *table_name)
+		tmp = g_strdup_printf ("%s.%s", table_name, field_name);
+	else
+		tmp = (gchar*) field_name;
+
+	guint field_id = gda_sql_builder_add_id (builder, tmp);
+
+	if (table_name)
+		g_free (tmp);
+
+	return field_id;
+}
+
 /**
  * gda_sql_builder_add_param
  * @builder: a #GdaSqlBuilder object
@@ -904,7 +951,7 @@ gda_sql_builder_add_id (GdaSqlBuilder *builder, const gchar *string)
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_add_param (GdaSqlBuilder *builder, const gchar *param_name, GType type, gboolean nullok)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
@@ -936,8 +983,8 @@ gda_sql_builder_add_param (GdaSqlBuilder *builder, const gchar *param_name, GTyp
  *
  * Since: 4.2
  */
-guint
-gda_sql_builder_add_cond (GdaSqlBuilder *builder, GdaSqlOperatorType op, guint op1, guint op2, guint op3)
+GdaSqlBuilderId
+gda_sql_builder_add_cond (GdaSqlBuilder *builder, GdaSqlOperatorType op, GdaSqlBuilderId op1, GdaSqlBuilderId op2, GdaSqlBuilderId op3)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -983,9 +1030,9 @@ gda_sql_builder_add_cond (GdaSqlBuilder *builder, GdaSqlOperatorType op, guint o
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_add_cond_v (GdaSqlBuilder *builder, GdaSqlOperatorType op,
-			    const guint *op_ids, gint op_ids_size)
+			    const GdaSqlBuilderId *op_ids, gint op_ids_size)
 {
 	gint i;
 	SqlPart **parts;
@@ -1026,7 +1073,7 @@ gda_sql_builder_add_cond_v (GdaSqlBuilder *builder, GdaSqlOperatorType op,
 
 typedef struct {
 	GdaSqlSelectTarget target; /* inheritance! */
-	guint part_id; /* copied from this part ID */
+	GdaSqlBuilderId part_id; /* copied from this part ID */
 } BuildTarget;
 
 /**
@@ -1043,8 +1090,8 @@ typedef struct {
  *
  * Since: 4.2
  */
-guint
-gda_sql_builder_select_add_target_id (GdaSqlBuilder *builder, guint table_id, const gchar *alias)
+GdaSqlBuilderId
+gda_sql_builder_select_add_target_id (GdaSqlBuilder *builder, GdaSqlBuilderId table_id, const gchar *alias)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -1075,7 +1122,7 @@ gda_sql_builder_select_add_target_id (GdaSqlBuilder *builder, guint table_id, co
 				idalias = TRUE;
 			else if (!alias && ! t->as)
 				idalias = TRUE;
-			
+
 			gchar *tmp;
 			tmp = gda_sql_expr_serialize (t->expr);
 			if (! strcmp (ser, tmp)) {
@@ -1126,10 +1173,10 @@ gda_sql_builder_select_add_target_id (GdaSqlBuilder *builder, guint table_id, co
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_select_add_target (GdaSqlBuilder *builder, const gchar *table_name, const gchar *alias)
 {
-	guint id;
+	GdaSqlBuilderId id;
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
 
@@ -1147,7 +1194,7 @@ gda_sql_builder_select_add_target (GdaSqlBuilder *builder, const gchar *table_na
 
 typedef struct {
 	GdaSqlSelectJoin join; /* inheritance! */
-	guint part_id; /* copied from this part ID */
+	GdaSqlBuilderId part_id; /* copied from this part ID */
 } BuilderJoin;
 
 /**
@@ -1169,11 +1216,11 @@ typedef struct {
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_select_join_targets (GdaSqlBuilder *builder,
-				     guint left_target_id, guint right_target_id,
+				     GdaSqlBuilderId left_target_id, GdaSqlBuilderId right_target_id,
 				     GdaSqlSelectJoinType join_type,
-				     guint join_expr)
+				     GdaSqlBuilderId join_expr)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -1263,7 +1310,7 @@ gda_sql_builder_select_join_targets (GdaSqlBuilder *builder,
  * Since: 4.2
  */
 void
-gda_sql_builder_join_add_field (GdaSqlBuilder *builder, guint join_id, const gchar *field_name)
+gda_sql_builder_join_add_field (GdaSqlBuilder *builder, GdaSqlBuilderId join_id, const gchar *field_name)
 {
 	g_return_if_fail (GDA_IS_SQL_BUILDER (builder));
 	g_return_if_fail (builder->priv->main_stmt);
@@ -1310,7 +1357,7 @@ gda_sql_builder_join_add_field (GdaSqlBuilder *builder, guint join_id, const gch
  * Since: 4.2
  */
 void
-gda_sql_builder_select_order_by (GdaSqlBuilder *builder, guint expr_id,
+gda_sql_builder_select_order_by (GdaSqlBuilder *builder, GdaSqlBuilderId expr_id,
 				 gboolean asc, const gchar *collation_name)
 {
 	SqlPart *part;
@@ -1355,7 +1402,7 @@ gda_sql_builder_select_order_by (GdaSqlBuilder *builder, guint expr_id,
  * Since: 4.2
  */
 void
-gda_sql_builder_select_set_distinct (GdaSqlBuilder *builder, gboolean distinct, guint expr_id)
+gda_sql_builder_select_set_distinct (GdaSqlBuilder *builder, gboolean distinct, GdaSqlBuilderId expr_id)
 {
 	GdaSqlStatementSelect *sel;
 	SqlPart *part = NULL;
@@ -1402,7 +1449,7 @@ gda_sql_builder_select_set_distinct (GdaSqlBuilder *builder, gboolean distinct,
  */
 void
 gda_sql_builder_select_set_limit (GdaSqlBuilder *builder,
-				  guint limit_count_expr_id, guint limit_offset_expr_id)
+				  GdaSqlBuilderId limit_count_expr_id, GdaSqlBuilderId limit_offset_expr_id)
 {
 	GdaSqlStatementSelect *sel;
 	SqlPart *part1 = NULL, *part2 = NULL;
@@ -1453,7 +1500,7 @@ gda_sql_builder_select_set_limit (GdaSqlBuilder *builder,
  * Since: 4.2
  */
 void
-gda_sql_builder_select_set_having (GdaSqlBuilder *builder, guint cond_id)
+gda_sql_builder_select_set_having (GdaSqlBuilder *builder, GdaSqlBuilderId cond_id)
 {
 	GdaSqlStatementSelect *sel;
 
@@ -1489,7 +1536,7 @@ gda_sql_builder_select_set_having (GdaSqlBuilder *builder, guint cond_id)
  * Since: 4.2
  */
 void
-gda_sql_builder_select_group_by (GdaSqlBuilder *builder, guint expr_id)
+gda_sql_builder_select_group_by (GdaSqlBuilder *builder, GdaSqlBuilderId expr_id)
 {
 	GdaSqlStatementSelect *sel;
 
@@ -1530,7 +1577,7 @@ gda_sql_builder_select_group_by (GdaSqlBuilder *builder, guint expr_id)
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_add_function (GdaSqlBuilder *builder, const gchar *func_name, ...)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
@@ -1541,14 +1588,14 @@ gda_sql_builder_add_function (GdaSqlBuilder *builder, const gchar *func_name, ..
 	GSList *list = NULL;
 	va_list ap;
 	SqlPart *part;
-	guint aid;
+	GdaSqlBuilderId aid;
 
 	expr = gda_sql_expr_new (NULL);
 	expr->func = gda_sql_function_new (GDA_SQL_ANY_PART (expr));
 	expr->func->function_name = g_strdup (func_name);
 
 	va_start (ap, func_name);
-	for (aid = va_arg (ap, guint); aid; aid = va_arg (ap, guint)) {
+	for (aid = va_arg (ap, GdaSqlBuilderId); aid; aid = va_arg (ap, GdaSqlBuilderId)) {
 		part = get_part (builder, aid, GDA_SQL_ANY_EXPR);
 		if (!part) {
 			expr->func->args_list = list;
@@ -1576,9 +1623,9 @@ gda_sql_builder_add_function (GdaSqlBuilder *builder, const gchar *func_name, ..
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_add_function_v (GdaSqlBuilder *builder, const gchar *func_name,
-				const guint *args, gint args_size)
+				const GdaSqlBuilderId *args, gint args_size)
 {
 	gint i;
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
@@ -1618,7 +1665,7 @@ gda_sql_builder_add_function_v (GdaSqlBuilder *builder, const gchar *func_name,
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_add_sub_select (GdaSqlBuilder *builder, GdaSqlStatement *sqlst)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
@@ -1715,9 +1762,9 @@ gda_sql_builder_compound_add_sub_select (GdaSqlBuilder *builder, GdaSqlStatement
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_add_case (GdaSqlBuilder *builder,
-			  guint test_expr, guint else_expr, ...)
+			  GdaSqlBuilderId test_expr, GdaSqlBuilderId else_expr, ...)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -1736,12 +1783,12 @@ gda_sql_builder_add_case (GdaSqlBuilder *builder,
 		expr->case_s->else_expr = (GdaSqlExpr*) use_part (pelse, GDA_SQL_ANY_PART (expr->case_s));
 
 	va_list ap;
-	guint id1;
+	GdaSqlBuilderId id1;
 	va_start (ap, else_expr);
-	for (id1 = va_arg (ap, guint); id1; id1 = va_arg (ap, guint)) {
-		guint id2;
+	for (id1 = va_arg (ap, GdaSqlBuilderId); id1; id1 = va_arg (ap, GdaSqlBuilderId)) {
+		GdaSqlBuilderId id2;
 		SqlPart *pwhen, *pthen;
-		id2 = va_arg (ap, guint);
+		id2 = va_arg (ap, GdaSqlBuilderId);
 		if (!id2)
 			goto cleanups;
 		pwhen = get_part (builder, id1, GDA_SQL_ANY_EXPR);
@@ -1782,10 +1829,10 @@ gda_sql_builder_add_case (GdaSqlBuilder *builder,
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_add_case_v (GdaSqlBuilder *builder,
-			    guint test_expr, guint else_expr,
-			    const guint *when_array, const guint *then_array, gint args_size)
+			    GdaSqlBuilderId test_expr, GdaSqlBuilderId else_expr,
+			    const GdaSqlBuilderId *when_array, const GdaSqlBuilderId *then_array, gint args_size)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
 	g_return_val_if_fail (builder->priv->main_stmt, 0);
@@ -1840,7 +1887,7 @@ gda_sql_builder_add_case_v (GdaSqlBuilder *builder,
  * Since: 4.2
  */
 GdaSqlExpr *
-gda_sql_builder_export_expression (GdaSqlBuilder *builder, guint id)
+gda_sql_builder_export_expression (GdaSqlBuilder *builder, GdaSqlBuilderId id)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), NULL);
 	g_return_val_if_fail (builder->priv->main_stmt, NULL);
@@ -1864,7 +1911,7 @@ gda_sql_builder_export_expression (GdaSqlBuilder *builder, guint id)
  *
  * Since: 4.2
  */
-guint
+GdaSqlBuilderId
 gda_sql_builder_import_expression (GdaSqlBuilder *builder, GdaSqlExpr *expr)
 {
 	g_return_val_if_fail (GDA_IS_SQL_BUILDER (builder), 0);
