@@ -493,12 +493,12 @@ init_from_table_node (DataSource *source, xmlNodePtr node, GError **error)
 				GdaMetaTableColumn *col;
 				col = GDA_META_TABLE_COLUMN (g_slist_nth_data (mlinked->columns, fk->fk_cols_array [0]));
 				g_assert (col);
-				const guint id1 = gda_sql_builder_add_id (b, fk->fk_names_array [0]);
+				const GdaSqlBuilderId id1 = gda_sql_builder_add_id (b, fk->fk_names_array [0]);
 				tmp = g_strdup_printf ("%s@%s", id ? (gchar*) id : (gchar*) fk_table,
 						       fk->ref_pk_names_array [0]);
-				const guint id2 = gda_sql_builder_add_param (b, tmp, col->gtype, FALSE);
+				const GdaSqlBuilderId id2 = gda_sql_builder_add_param (b, tmp, col->gtype, FALSE);
 				g_free (tmp);
-				const guint id_cond = gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ, id1, id2, 0);
+				const GdaSqlBuilderId id_cond = gda_sql_builder_add_cond (b, GDA_SQL_OPERATOR_TYPE_EQ, id1, id2, 0);
 				gda_sql_builder_set_where (b, id_cond);
 			}
 			else {
