@@ -23,9 +23,12 @@
 
 #include <glib/gi18n-lib.h>
 #include <string.h>
-#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #ifdef HAVE_GTKSOURCEVIEW
+  #ifdef GTK_DISABLE_SINGLE_INCLUDES
+    #undef GTK_DISABLE_SINGLE_INCLUDES
+  #endif
+
   #include <gtksourceview/gtksourceview.h>
   #include <gtksourceview/gtksourcelanguagemanager.h>
   #include <gtksourceview/gtksourcebuffer.h>
@@ -45,7 +48,7 @@
 
 static void query_editor_history_batch_add_item (QueryEditorHistoryBatch *qib,
 						 QueryEditorHistoryItem *qih);
-static void query_editor_history_batch_del_item (QueryEditorHistoryBatch *qib,
+static void query_editor_history_batch_del_item (QueryEditor *editor, QueryEditorHistoryBatch *qib,
 						 QueryEditorHistoryItem *qih);
 
 typedef void (* CreateTagsFunc) (QueryEditor *editor, const gchar *language);
@@ -606,11 +609,13 @@ text_view_expose_event (GtkTextView *tv, GdkEventExpose *event, QueryEditor *edi
 	gint win_y;
 	GdkGC *gc;
 	gint margin;
+	GtkTextBuffer *tbuffer;
 	
-	gtk_text_buffer_get_iter_at_mark (tv->buffer, &cur, editor->priv->hist_focus->start_mark);	
+	tbuffer = gtk_text_view_get_buffer (tv);
+	gtk_text_buffer_get_iter_at_mark (tbuffer, &cur, editor->priv->hist_focus->start_mark);	
 	gtk_text_view_get_line_yrange (tv, &cur, &y, &height);
 	
-	gtk_text_buffer_get_iter_at_mark (tv->buffer, &cur, editor->priv->hist_focus->end_mark);	
+	gtk_text_buffer_get_iter_at_mark (tbuffer, &cur, editor->priv->hist_focus->end_mark);	
 	gtk_text_view_get_line_yrange (tv, &cur, &ye, &heighte);
 	height = ye - y;
 
@@ -620,7 +625,7 @@ text_view_expose_event (GtkTextView *tv, GdkEventExpose *event, QueryEditor *edi
 		list = g_slist_last (editor->priv->hist_focus->batch->hist_items);
 		if (list) {
 			hdata = g_hash_table_lookup (editor->priv->hash, list->data);
-			gtk_text_buffer_get_iter_at_mark (tv->buffer, &cur, hdata->end_mark);	
+			gtk_text_buffer_get_iter_at_mark (tbuffer, &cur, hdata->end_mark);	
 			gtk_text_view_get_line_yrange (tv, &cur, &ye, &heighte);
 			height = ye - y;
 		}
@@ -643,7 +648,13 @@ text_view_expose_event (GtkTextView *tv, GdkEventExpose *event, QueryEditor *edi
 	redraw_rect.width = visible_rect.width;
 	redraw_rect.height = visible_rect.height;
 	
-	gc = GTK_WIDGET (tv)->style->bg_gc[GTK_WIDGET_STATE (GTK_WIDGET (tv))];
+	GtkStateType state;
+#if GTK_CHECK_VERSION(2,18,0)
+	state = gtk_widget_get_state (GTK_WIDGET (tv));
+#else
+	state = GTK_WIDGET_STATE (GTK_WIDGET (tv));
+#endif
+	gc = gtk_widget_get_style (GTK_WIDGET (tv))->bg_gc[state];
 	margin = gtk_text_view_get_left_margin (tv);
 	
 	gdk_draw_rectangle (event->window,
@@ -768,25 +779,30 @@ query_editor_grab_focus (GtkWidget *widget)
 static void
 hist_data_free_all (QueryEditor *editor)
 {
+	if (editor->priv->hist_focus) {
+		hist_item_data_unref (editor->priv->hist_focus);
+		editor->priv->hist_focus = NULL;
+	}
+
 	if (editor->priv->ts_timeout_id) {
 		g_source_remove (editor->priv->ts_timeout_id);
 		editor->priv->ts_timeout_id = 0;
 	}
-	if (editor->priv->batches_list) {
-		g_slist_foreach (editor->priv->batches_list, (GFunc) query_editor_history_batch_unref, NULL);
-		g_slist_free (editor->priv->batches_list);
-		editor->priv->batches_list = NULL;
-	}
 
 	if (editor->priv->hash) {
 		g_hash_table_destroy (editor->priv->hash);
 		editor->priv->hash = NULL;
 	}
 
-	if (editor->priv->hist_focus) {
-		hist_item_data_unref (editor->priv->hist_focus);
-		editor->priv->hist_focus = NULL;
-	}	
+	if (editor->priv->insert_into_batch) {
+		query_editor_history_batch_unref (editor->priv->insert_into_batch);
+		editor->priv->insert_into_batch = NULL;
+	}
+	if (editor->priv->batches_list) {
+		g_slist_foreach (editor->priv->batches_list, (GFunc) query_editor_history_batch_unref, NULL);
+		g_slist_free (editor->priv->batches_list);
+		editor->priv->batches_list = NULL;
+	}
 }
 
 static void
@@ -1423,6 +1439,20 @@ query_editor_get_current_history_batch (QueryEditor *editor)
 		return NULL;
 }
 
+/**
+ * query_editor_history_is_empty
+ * @editor: a #QueryEditor widget.
+ *
+ * Returns: %TRUE if @editor doe snot have any history item
+ */
+gboolean
+query_editor_history_is_empty (QueryEditor *editor)
+{
+	g_return_val_if_fail (QUERY_IS_EDITOR (editor), FALSE);
+	g_return_val_if_fail (editor->priv->mode == QUERY_EDITOR_HISTORY, FALSE);
+
+	return editor->priv->batches_list ? FALSE : TRUE;
+}
 
 /**
  * query_editor_del_current_history_item
@@ -1466,10 +1496,7 @@ query_editor_del_current_history_item (QueryEditor *editor)
 	g_hash_table_remove (editor->priv->hash, hdata->tag);
 	
 	g_assert (hdata->batch);
-	query_editor_history_item_ref (hdata->item);
-	query_editor_history_batch_del_item (hdata->batch, hdata->item);
-	g_signal_emit (editor, query_editor_signals[HISTORY_ITEM_REMOVED], 0, hdata->item);
-	query_editor_history_item_unref (hdata->item);
+	query_editor_history_batch_del_item (editor, hdata->batch, hdata->item);
 
 	if (! hdata->batch->hist_items) {
 		/* remove hdata->batch */
@@ -1570,7 +1597,7 @@ query_editor_del_history_batch (QueryEditor *editor, QueryEditorHistoryBatch *ba
 		
 		g_hash_table_remove (editor->priv->hash, hdata->item);
 		g_hash_table_remove (editor->priv->hash, hdata->tag);
-		query_editor_history_batch_del_item (batch, (QueryEditorHistoryItem*) list->data);
+		query_editor_history_batch_del_item (editor, batch, (QueryEditorHistoryItem*) list->data);
 	}
 	
 	/* remove batch */
@@ -1799,6 +1826,9 @@ query_editor_history_batch_new (GTimeVal run_time, GdaSet *params)
 	if (params)
 		qib->params = gda_set_copy (params);
 
+#ifdef QUERY_EDITOR_DEBUG
+	g_print ("\t%s() => %p\n", __FUNCTION__, qib);
+#endif
 	return qib;
 }
 
@@ -1824,7 +1854,14 @@ query_editor_history_batch_unref (QueryEditorHistoryBatch *qib)
 			g_object_unref (qib->params);
 
 		g_free (qib);
+#ifdef QUERY_EDITOR_DEBUG
+		g_print ("\t%s() => %p\n", __FUNCTION__, qib);
+#endif
 	}
+#ifdef QUERY_EDITOR_DEBUG
+	else
+		g_print ("\tFAILED %s() => %p:%d\n", __FUNCTION__, qib, qib->ref_count);
+#endif
 }
 
 static void
@@ -1836,11 +1873,13 @@ query_editor_history_batch_add_item (QueryEditorHistoryBatch *qib, QueryEditorHi
 }
 
 static void
-query_editor_history_batch_del_item (QueryEditorHistoryBatch *qib, QueryEditorHistoryItem *qih)
+query_editor_history_batch_del_item (QueryEditor *editor, QueryEditorHistoryBatch *qib, QueryEditorHistoryItem *qih)
 {
 	g_return_if_fail (qib);
 	g_return_if_fail (qih);
 	qib->hist_items = g_slist_remove (qib->hist_items, qih);
+
+	g_signal_emit (editor, query_editor_signals[HISTORY_ITEM_REMOVED], 0, qih);
 	query_editor_history_item_unref (qih);
 }
 
@@ -1862,6 +1901,9 @@ query_editor_history_item_new (const gchar *sql, GObject *result, GError *error)
 	if (error)
 		qih->exec_error = g_error_copy (error);
 
+#ifdef QUERY_EDITOR_DEBUG
+	g_print ("\t%s() => %p\n", __FUNCTION__, qih);
+#endif
 	return qih;
 }
 
@@ -1885,7 +1927,14 @@ query_editor_history_item_unref (QueryEditorHistoryItem *qih)
 		if (qih->exec_error)
 			g_error_free (qih->exec_error);
 		g_free (qih);
+#ifdef QUERY_EDITOR_DEBUG
+		g_print ("\t%s() => %p\n", __FUNCTION__, qih);
+#endif
 	}
+#ifdef QUERY_EDITOR_DEBUG
+	else
+		g_print ("\tFAILED %s() => %p:%d\n", __FUNCTION__, qih, qih->ref_count);
+#endif
 }
 
 /*
